@@ -35,7 +35,7 @@ class MemfaultCliClickContext(object):
 
     def _find_obj_or_raise(self, name):
         value = self.obj.get(name)
-        if not value:
+        if value is None:
             option = name.replace("_", "-")
             raise click.exceptions.UsageError(f'Missing option "--{option}".')
         return value
@@ -105,14 +105,30 @@ class MemfaultCliClickContext(object):
             return APP_BASE_URL
         return url
 
+    @property
+    def chunks_url(self):
+        CHUNKS_BASE_URL = "https://chunks.memfault.com"
+        url = self.obj.get("url")
+        if url is None:
+            return CHUNKS_BASE_URL
+        return url
+
     @property
     def hardware_version(self):
         return self.obj.get("hardware_version", None)
 
+    @property
+    def device_serial(self):
+        return self._find_obj_or_raise("device_serial")
+
     @property
     def build_variant(self):
         return self._find_obj_or_raise("build_variant")
 
+    @property
+    def must_pass_through(self):
+        return self._find_obj_or_raise("must_pass_through")
+
     @property
     def android_package_info(self) -> Optional[PackageInfo]:
         package = self.obj.get("package")
